from zope.publisher.browser import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.CMFCore.utils import getToolByName


class UserNotify(BrowserView):

    template = ViewPageTemplateFile("notify_user_html.pt")

    def __call__(self, **kwargs):
        acl_users = getToolByName(self.context, 'acl_users')
        user = acl_users.getUserById(kwargs['username'])
        self.username = user.getUserName()
        return self.template(**kwargs)



from ftw.tabbedview.browser.tabbed import TabbedView
from ftw.usermanagement import user_management_factory as _
from zope.interface import implements
from ftw.tabbedview.interfaces import INoExtJS


class ManagementTabbedView(TabbedView):
    """TabbedView for User/Groups management"""

    implements(INoExtJS)

    def __init__(self, context, request):
        super(ManagementTabbedView, self).__init__(context, request)

        if not request.get('disable_border'):
            request.set('disable_border', '1')

        request.set('disable_plone.rightcolumn', True)
        request.set('disable_plone.leftcolumn', True)

    def get_tabs(self):
        """Returns a list of dicts containing the tabs definitions"""

        translate = self.context.translate
        return [
            {
                'id': 'users_management',
                'class': '',
                'description': translate(
                    _('msg_usersDescription',
                      default='Users-management')),
            },

            {
                'id': 'groups_management',
                'class': '',
                'description': translate(
                    _('msg_groupsDescription',
                      default='Groups-management')),
            }]
